"""ABOM — the Agent Bill of Materials. Scan, sign, gate, and verify AI agents."""

__version__ = "0.1.17"

from .anchor import TimestampError, anchor_head
from .broker import McpBroker, connect_http
from .gate import Action, ActionDenied, Decision, Gate, Verdict, evaluate
from .merkle import (
    MerkleLog,
    PersistentMerkleLog,
    verify_consistency_hex,
    verify_inclusion_hex,
)
from .signer import KMSSigner, LocalSigner, Signer, sign_payload, verify_payload
from .witness import Witness, WitnessRejected

__all__ = [
    "Action",
    "ActionDenied",
    "Decision",
    "Gate",
    "Verdict",
    "evaluate",
    "MerkleLog",
    "PersistentMerkleLog",
    "verify_inclusion_hex",
    "verify_consistency_hex",
    "Signer",
    "LocalSigner",
    "KMSSigner",
    "sign_payload",
    "verify_payload",
    "McpBroker",
    "connect_http",
    "Witness",
    "WitnessRejected",
    "anchor_head",
    "TimestampError",
]
